#####################################################################################
###
### Acme Software Works, Inc.
###
### Created June 16, 2019 by Don Dugger
###
### <PRE>
### Copyright 2019 Acme Software Works, Inc.
### 
### Redistribution and use in source and binary forms, with or without
### modification, are permitted provided that the following conditions are met:
### 
### 1. Redistributions of source code must retain the above copyright notice,
###    this list of conditions and the following disclaimer.
### 
### 2. Redistributions in binary form must reproduce the above copyright notice,
###    this list of conditions and the following disclaimer in the documentation
###    and/or other materials provided with the distribution.
### 
### THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
### AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
### IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
### ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
### LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
### CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
### GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
### HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
### LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
### OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
### <PRE>
#####################################################################################
import calendar
from datetime import datetime
import subprocess

######### Configuration ##################
# Make changes as needed

# Database configuration
config = {
  'user': 'username',
  'password': 'password',
  'host': '127.0.0.1',
  'database': 'taskprompt',
  'raise_on_warnings': True
}

# Location configuration
BIN_DIR = "/home/username/bin/"
UI_DIR = "/home/username/bin/"
SPEAK = "/usr/local/bin/flite"
PROMPT_DATE_FORMAT = "%A %B %e, %Y  %I:%M %p"

######### End of Configuration #############

######### General functions ################

#############################################
# Speak the text.
# The path to 'flite' or the speaking program may need
# to be changed.
def sayit(text):
    args = [SPEAK,'-t "{}"'.format(text)]
    res = subprocess.run(args)

###########################################################
# Calculate the nth weekday of the month given the date and
# the 'month modifier spec'. Which is the numeric operator
# followed by the three character weekday abbreviation. 
def monthDay(the_date, spec):
    # Pull the year and month out of the
    # datetime object as integers.
    year = int(the_date.strftime("%Y"))
    month = int(the_date.strftime("%m"))
    # The last 3 character of the spec are the weekday
    # and the list we get from the calendar object will
    # have the first character the weekday capitalized.
    # The rest the spec is the numeric operator. We will
    # change it to lower case so that the spec is case
    # insensitive.
    weekday = spec[-3:].lower().capitalize()
    nth_day = spec[:-3].lower()
    # Now because 'LastDay' is a special case we get
    # done with it.
    if weekday == "Day" and nth_day == "last":
        first_last = calendar.monthrange(year,month)
        return first_last[1]
    # Get the list of abbreviated weekday names. 
    DAY_NAMES = [day for day in calendar.day_abbr]
    # Get the index used by the calendar object for
    # the day that is in the spec.
    day_index = DAY_NAMES.index(weekday)
    # Then find it in the calendar ( A little magic )
    # If you print out what the 'calendar' object returns
    # from the 'monthcalendar' method this will make more
    # sense.
    possible_dates = [
            week[day_index]
            for week in calendar.monthcalendar(year, month)
                if week[day_index]] # remove zeroes
    # Then finally translate the numeric operator. 
    if   nth_day == 'last':
        day_index = -1
    elif nth_day == 'first':
        day_index = 0 
    elif nth_day == 'second':
        day_index = 1 
    elif nth_day == 'third':
        day_index = 2 
    elif nth_day == 'fourth':
        day_index = 3 
    return possible_dates[day_index]

