#####################################################################################
###
### Acme Software Works, Inc.
###
### Created June 16, 2019 by Don Dugger
###
### <PRE>
### Copyright 2019 Acme Software Works, Inc.
### 
### Redistribution and use in source and binary forms, with or without
### modification, are permitted provided that the following conditions are met:
### 
### 1. Redistributions of source code must retain the above copyright notice,
###    this list of conditions and the following disclaimer.
### 
### 2. Redistributions in binary form must reproduce the above copyright notice,
###    this list of conditions and the following disclaimer in the documentation
###    and/or other materials provided with the distribution.
### 
### THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
### AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
### IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
### ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
### LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
### CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
### GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
### HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
### LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
### OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
### <PRE>
#####################################################################################
import mysql.connector
from libprompt import config


# A simple to abstract access to the prompt database table. 
class PromptDB():
    # The constructor gets the configuration and connects to MySql.
    def __init__(self):
        self.config = config
        self.cnx = None
        self.setup()

    def setup(self):
        self.cnx = mysql.connector.connect(**self.config)
        
    # Makes sure the connect is closed.
    def __del__(self):
        if self.cnx != None:
            self.cnx.close()
    # Safe way to close.
    def close(self):
        if self.cnx != None:
            self.cnx.close()
        self.cnx = None

    # Get the full list of prompts.
    def fetchAllPrompts(self):
        cursor = self.cnx.cursor()
        cursor.execute("SELECT id,date,time,freq,text,count FROM tasks")
        return cursor.fetchall();

    # Get a prompt by the ID.
    def fetchOnePrompt(self,id):
        cursor = self.cnx.cursor()
        cursor.execute("SELECT id,date,time,freq,text,count FROM tasks WHERE id ={}".format(id))
        return cursor.fetchone();

    # Delete a prompt by ID.
    def delPrompt(self,id):
        cursor = self.cnx.cursor()
        cursor.execute("DELETE FROM tasks WHERE id={}".format(id))

    # Add a prompt to the table and return the ID.
    def addPrompt(self,date_str,time_str,freq_str,task_str,count):
        cursor = self.cnx.cursor()
        cursor.execute("INSERT INTO tasks (date,time,freq,text,count) VALUES ('{}','{}','{}','{}','{}')".format(date_str,time_str,freq_str,task_str,count))
        return int(cursor.lastrowid)
        
    # Update the prompt by ID.
    def editPrompt(self,id,date_str,time_str,freq_str,task_str):
        cursor = self.cnx.cursor()
        cursor.execute("UPDATE tasks SET date='{}',time='{}',freq='{}',text='{}' WHERE id={}".format(date_str,time_str,freq_str,task_str,id))
        
    # Update the prompt date by ID. 
    def setDate(self,id,date_str):
        cursor = self.cnx.cursor()
        cursor.execute("UPDATE tasks SET date='{}' WHERE id={}".format(date_str,id))

    # Update the count field by ID.
    def setCount(self,id,count):
        cursor = self.cnx.cursor()
        cursor.execute("UPDATE tasks SET count='{}' WHERE id={}".format(count,id))
        
